@@ -1,17 +1,25 @@
+// -*- c-basic-offset: 2 -*-
+/* ----------------------------------------------------------------------------
+ * Licq - A ICQ Client for Unix
+ * Copyright (C) 1998 - 2003 Licq developers
+ *
+ * This program is licensed under the terms found in the LICENSE file.
+ */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include "remoteserver.h"
+#include "licq_remoteserver.h"
+#include "licq_constants.h"
 
-
-ICQRemoteServers::ICQRemoteServers(void)
+ICQRemoteServers::ICQRemoteServers()
 {
    currentServerNum = -1;
 }
 
 
-unsigned short ICQRemoteServers::numServers(void)
+unsigned short ICQRemoteServers::numServers()
 {
    return(servers.size());
 }
@@ -23,13 +31,13 @@ void ICQRemoteServers::addServer(char *theName, unsigned short thePort)
 }
 
 
-RemoteServer *ICQRemoteServers::current(void)
+RemoteServer *ICQRemoteServers::current()
 {
    return (currentServerNum >= 0 ? servers[currentServerNum] : NULL);
 }
 
 
-void ICQRemoteServers::next(void)
+void ICQRemoteServers::next()
 {
    if (servers.size() == 0) return;
    currentServerNum++;
@@ -57,11 +65,11 @@ RemoteServer::RemoteServer(char *theName, unsigned short thePort)
 
 
 //----RemoteServer::data retrieval functions-------------------------------------------------------
-char *RemoteServer::name(void)             { return(nameVal); }
-unsigned short RemoteServer::port(void)    { return(portVal); }
+char *RemoteServer::name()             { return(nameVal); }
+unsigned short RemoteServer::port()    { return(portVal); }
 
 //-----RemoteServer::retry functions---------------------------------------------------------------
-bool RemoteServer::retry(void)     { return (retries < MAX_SERVER_RETRIES); }
-void RemoteServer::retrying(void)  { retries++; }
-void RemoteServer::ok(void)        { retries = 0; }
+bool RemoteServer::retry()     { return (retries < MAX_SERVER_RETRIES); }
+void RemoteServer::retrying()  { retries++; }
+void RemoteServer::ok()        { retries = 0; }
 
